@@ -346,6 +346,150 @@ class Facility(Network):
         )
 
 
+class Pump(Node):
+    """
+    Parameters
+    ----------
+    id : str
+        Pump ID
+
+    input_contents : ContentsType
+        Contents entering the pump
+
+    output_contents : ContentsType
+        Contents leaving the pump
+
+    elevation : int
+        Elevation of the pump in meters above sea level
+
+    horsepower : int
+        Horsepower of a single pump
+
+    num_units : int
+        Number of pumps running in parallel
+
+    min_flow : int
+        Minimum flow rate supplied by the pump
+
+    max_flow : int
+        Maximum flow rate supplied by the pump
+
+    avg_flow : int
+        Average flow rate supplied by the pump
+
+    pump_type : PumpType
+        Type of pump (either VFD or constant)
+
+    tags : dict of Tag
+        Data tags associated with this pump
+
+    Attributes
+    ----------
+    id : str
+        Pump ID
+
+    input_contents : ContentsType
+        Contents entering the pump
+
+    output_contents : ContentsType
+        Contents leaving the pump
+
+    elevation : int
+        Elevation of the pump in meters above sea level
+
+    horsepower : int
+        Horsepower of a single pump
+
+    num_units : int
+        Number of pumps running in parallel
+
+    flow_rate : tuple
+        Tuple of minimum, maximum, and average pump flow rate
+
+    tags : dict of Tag
+        Data tags associated with this pump
+
+    energy_efficiency : function
+        Function which takes in the current flow rate and returns the energy
+        required to pump at that rate
+    """
+
+    def __init__(
+        self,
+        id,
+        input_contents,
+        output_contents,
+        min_flow,
+        max_flow,
+        avg_flow,
+        elevation,
+        horsepower,
+        num_units,
+        pump_type=utils.PumpType.Constant,
+        tags={},
+    ):
+        self.id = id
+        self.input_contents = input_contents
+        self.output_contents = output_contents
+        self.elevation = elevation
+        self.pump_type = pump_type
+        self.horsepower = horsepower
+        self.num_units = num_units
+        self.tags = tags
+        self.set_flow_rate(min_flow, max_flow, avg_flow)
+        self.set_energy_efficiency(None)
+
+    def __repr__(self):
+        return (
+            f"<wwtp_configuration.connection.Pump id:{self.id} "
+            f"input_contents:{self.input_contents} "
+            f"output_contents:{self.output_contents} "
+            f"flow_rate:{self.flow_rate} elevation:{self.elevation} "
+            f"horsepower:{self.horsepower} num_units:{self.num_units} "
+            f"tags:{self.tags}>\n"
+        )
+
+    def __eq__(self, other):
+        # don't attempt to compare against unrelated types
+        if not isinstance(other, self.__class__):
+            return NotImplemented
+
+        return (
+            self.id == other.id
+            and self.input_contents == other.input_contents
+            and self.output_contents == other.output_contents
+            and self.elevation == other.elevation
+            and self.pump_type == other.pump_type
+            and self.horsepower == other.horsepower
+            and self.num_units == other.num_units
+            and self.tags == other.tags
+            and self.flow_rate == other.flow_rate
+            and self.energy_efficiency == other.energy_efficiency
+        )
+
+    def set_pump_type(self, pump_type):
+        """Set the pump curve to the given function
+
+        Parameters
+        ----------
+        pump_type : PumpType
+        """
+        # TODO: check that pump_type is a valid enum
+        self.pump_type = pump_type
+
+    def set_energy_efficiency(self, pump_curve):
+        """Set the pump curve to the given function
+
+        Parameters
+        ----------
+        pump_curve : function
+            function which takes in the current flow rate and returns the energy
+            required to pump at that rate
+        """
+        # TODO: type check that pump_curve is a function
+        self.energy_efficiency = pump_curve
+
+
 class Tank(Node):
     """
     Parameters
